var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/converters/index.ts
var converters_exports = {};
__export(converters_exports, {
  DateParamType: () => DateParamType,
  arrayParam: () => arrayParam,
  booleanParam: () => booleanParam,
  dateParam: () => dateParam,
  numberParam: () => numberParam,
  objectParam: () => objectParam,
  stringParam: () => stringParam
});
module.exports = __toCommonJS(converters_exports);

// src/converters/array.ts
function arrayParam(elementConfig) {
  return {
    serialize: (values) => {
      if (!values) {
        return null;
      }
      return values.map(elementConfig.serialize);
    },
    deserialize: (values) => {
      if (!values) {
        return void 0;
      }
      if (!Array.isArray(values)) {
        return [elementConfig.deserialize(values)];
      }
      return values.map(elementConfig.deserialize);
    }
  };
}

// src/converters/boolean.ts
var booleanParam = () => ({
  serialize: (value) => typeof value === "boolean" ? value.toString() : null,
  deserialize: (value) => {
    if (value === "true")
      return true;
    if (value === "false")
      return false;
    return void 0;
  }
});

// src/converters/date.ts
var DateParamType = /* @__PURE__ */ ((DateParamType2) => {
  DateParamType2[DateParamType2["Date"] = 0] = "Date";
  DateParamType2[DateParamType2["DateTime"] = 1] = "DateTime";
  return DateParamType2;
})(DateParamType || {});
function serialize(value, options) {
  try {
    const serializedValue = value == null ? void 0 : value.toISOString();
    return (options == null ? void 0 : options.dateType) === 0 /* Date */ ? (serializedValue == null ? void 0 : serializedValue.substring(0, 10)) ?? null : serializedValue ?? null;
  } catch {
    return null;
  }
}
function deserialize(value, options) {
  const stringValue = value;
  if (stringValue === null || stringValue === void 0) {
    return void 0;
  }
  try {
    const date = new Date(stringValue);
    return isNaN(date.getTime()) ? void 0 : date;
  } catch {
    return void 0;
  }
}
var dateParam = (options) => {
  return {
    serialize: (value) => serialize(value, options),
    deserialize: (value) => deserialize(value, options)
  };
};

// src/converters/number.ts
var numberParam = () => ({
  serialize: (value) => Number.isFinite(value) ? `${value}` : null,
  deserialize: (value) => {
    try {
      const parsedValue = Number.parseFloat(value);
      return Number.isFinite(parsedValue) ? parsedValue : void 0;
    } catch {
      return void 0;
    }
  }
});

// src/converters/object.ts
function objectParam() {
  return {
    serialize: (value) => {
      if (value === void 0 || value === null || typeof value !== "object") {
        return null;
      }
      return encodeURIComponent(JSON.stringify(value));
    },
    deserialize: (value) => {
      if (value === null || Array.isArray(value)) {
        return void 0;
      }
      try {
        return JSON.parse(decodeURIComponent(value));
      } catch {
        return void 0;
      }
    }
  };
}

// src/converters/string.ts
var stringParam = () => ({
  serialize: (value) => value ?? null,
  deserialize: (value) => value ? `${value}` : void 0
});
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  DateParamType,
  arrayParam,
  booleanParam,
  dateParam,
  numberParam,
  objectParam,
  stringParam
});
//# sourceMappingURL=index.js.map