var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  DateParamType: () => DateParamType,
  arrayParam: () => arrayParam,
  booleanParam: () => booleanParam,
  dateParam: () => dateParam,
  default: () => useQueryParamPlugin,
  numberParam: () => numberParam,
  objectParam: () => objectParam,
  stringParam: () => stringParam,
  useQueryParam: () => useQueryParam,
  withDefault: () => withDefault
});
module.exports = __toCommonJS(src_exports);

// src/converters/array.ts
function arrayParam(elementConfig) {
  return {
    serialize: (values) => {
      if (!values) {
        return null;
      }
      return values.map(elementConfig.serialize);
    },
    deserialize: (values) => {
      if (!values) {
        return void 0;
      }
      if (!Array.isArray(values)) {
        return [elementConfig.deserialize(values)];
      }
      return values.map(elementConfig.deserialize);
    }
  };
}

// src/converters/boolean.ts
var booleanParam = () => ({
  serialize: (value) => typeof value === "boolean" ? value.toString() : null,
  deserialize: (value) => {
    if (value === "true")
      return true;
    if (value === "false")
      return false;
    return void 0;
  }
});

// src/converters/date.ts
var DateParamType = /* @__PURE__ */ ((DateParamType2) => {
  DateParamType2[DateParamType2["Date"] = 0] = "Date";
  DateParamType2[DateParamType2["DateTime"] = 1] = "DateTime";
  return DateParamType2;
})(DateParamType || {});
function serialize(value, options) {
  try {
    const serializedValue = value == null ? void 0 : value.toISOString();
    return (options == null ? void 0 : options.dateType) === 0 /* Date */ ? (serializedValue == null ? void 0 : serializedValue.substring(0, 10)) ?? null : serializedValue ?? null;
  } catch {
    return null;
  }
}
function deserialize(value, options) {
  const stringValue = value;
  if (stringValue === null || stringValue === void 0) {
    return void 0;
  }
  try {
    const date = new Date(stringValue);
    return isNaN(date.getTime()) ? void 0 : date;
  } catch {
    return void 0;
  }
}
var dateParam = (options) => {
  return {
    serialize: (value) => serialize(value, options),
    deserialize: (value) => deserialize(value, options)
  };
};

// src/converters/number.ts
var numberParam = () => ({
  serialize: (value) => Number.isFinite(value) ? `${value}` : null,
  deserialize: (value) => {
    try {
      const parsedValue = Number.parseFloat(value);
      return Number.isFinite(parsedValue) ? parsedValue : void 0;
    } catch {
      return void 0;
    }
  }
});

// src/converters/object.ts
function objectParam() {
  return {
    serialize: (value) => {
      if (value === void 0 || value === null || typeof value !== "object") {
        return null;
      }
      return encodeURIComponent(JSON.stringify(value));
    },
    deserialize: (value) => {
      if (value === null || Array.isArray(value)) {
        return void 0;
      }
      try {
        return JSON.parse(decodeURIComponent(value));
      } catch {
        return void 0;
      }
    }
  };
}

// src/converters/string.ts
var stringParam = () => ({
  serialize: (value) => value ?? null,
  deserialize: (value) => value ? `${value}` : void 0
});

// src/core/useQueryParam.ts
var import_vue = require("vue");
var import_vue_router = require("vue-router");

// src/plugin/config.ts
var PROVIDE_KEY = "vue-use-query-param";

// src/core/useQueryParam.ts
function mergeUpdates(updates) {
  return updates.reduce((result, update) => {
    return {
      ...result,
      [update.name]: update.value
    };
  }, {});
}
function useQueryParam(name, { serialize: serialize2, deserialize: deserialize2 }) {
  const router = (0, import_vue_router.useRouter)();
  const route = (0, import_vue_router.useRoute)();
  const plugin = (0, import_vue.inject)(PROVIDE_KEY);
  async function updateUrl(updates) {
    const mergedUpdates = mergeUpdates(updates);
    const mergedQuery = { ...route.query, ...mergedUpdates };
    const nullProperties = Object.entries(mergedQuery).filter(([_, value]) => value === null).map(([key, _]) => key);
    nullProperties.forEach((key) => delete mergedQuery[key]);
    await router.replace({
      query: mergedQuery
    });
  }
  function setQueryParam(value) {
    const serializedValue = serialize2(value);
    plugin == null ? void 0 : plugin.queueUpdate({ name, value: serializedValue }, updateUrl);
  }
  return (0, import_vue.computed)({
    get: () => deserialize2(route.query[name]),
    set: (value) => setQueryParam(value)
  });
}

// src/core/withDefault.ts
function withDefault({ serialize: serialize2, deserialize: deserialize2 }, defaultValue) {
  return {
    serialize: serialize2,
    deserialize: (value) => deserialize2(value) ?? defaultValue
  };
}

// src/plugin/index.ts
var import_vue2 = require("vue");
var useQueryParamPlugin = {
  install: (app, options) => {
    const queue = (0, import_vue2.ref)([]);
    const timeoutRef = (0, import_vue2.ref)(null);
    function queueUpdate(update, urlUpdate) {
      if (timeoutRef.value) {
        clearTimeout(timeoutRef.value);
      }
      queue.value.push(update);
      timeoutRef.value = setTimeout(async () => {
        await urlUpdate(queue.value);
        queue.value = [];
        timeoutRef.value = null;
      }, options.debounceDelay ?? 0);
    }
    app.provide(PROVIDE_KEY, { queueUpdate });
  }
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  DateParamType,
  arrayParam,
  booleanParam,
  dateParam,
  numberParam,
  objectParam,
  stringParam,
  useQueryParam,
  withDefault
});
//# sourceMappingURL=index.js.map